//+------------------------------------------------------------------+
//|                                            TimeSet_MAForceCr.mq4 |
//|                             Copyright  2012, JimsTradingMachine |
//|                                                                  |
//+------------------------------------------------------------------+
#define MAGICMA  20050610

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.02;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 3;                // moving period for Wato
extern double MovingShift        = 3;                // moving shift for Wato
extern double tf                 = 5;
extern double F                  = 4; // Force period
datetime TimeStamp               =0;
extern double TimeOpen     = 08;
extern double TimeClose    = 14;
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double xa; double xb; double xc; double xsp; double xxa; double xxb; double xxc; double xxsp;
   double atr; double atr2;
   double sto;
   double rsi;
   double atrs; 
   double atrl;
   double atrbs; 
   double atrbl;
   double atrv;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- Force indicator      
   double valb; double val; double val2; double val3; double val1; double val21; double val31;         
   double val5; double val25; double val35; double val16; double val26; double val36;
//---- Moving AVE indicator      
   double ma; double mae; double mau; double maa; double maee; double mauu;     

//----get Force Indicator   
   val=iForce(NULL,0,F,MODE_LWMA,PRICE_WEIGHTED,0);   
   val2=iForce("EURGBP",0,F,MODE_SMA,PRICE_CLOSE,0);
   val3=iForce("GBPUSD",0,F,MODE_SMA,PRICE_CLOSE,0);
   val1=iForce(NULL,0,F,MODE_SMA,PRICE_CLOSE,1);
   val21=iForce("EURGBP",0,F,MODE_SMA,PRICE_CLOSE,1);
   val31=iForce("GBPUSD",0,F,MODE_SMA,PRICE_CLOSE,1); 
   val5=iForce(NULL,5,F,MODE_SMA,PRICE_CLOSE,0);   
   val25=iForce("EURGBP",5,F,MODE_SMA,PRICE_CLOSE,0);
   val35=iForce("GBPUSD",5,F,MODE_SMA,PRICE_CLOSE,0);
   val16=iForce(NULL,5,F,MODE_SMA,PRICE_CLOSE,1);
   val26=iForce("EURGBP",5,F,MODE_SMA,PRICE_CLOSE,1);
   val36=iForce("GBPUSD",5,F,MODE_SMA,PRICE_CLOSE,1);
  
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_LWMA,PRICE_WEIGHTED,3);
   mae=iMA("EURGBP",0,MovingPeriod,MovingShift,MODE_LWMA,PRICE_WEIGHTED,3);
   mau=iMA("GBPUSD",0,MovingPeriod,MovingShift,MODE_LWMA,PRICE_WEIGHTED,3);
   maa=iMA(NULL,0,MovingPeriod,MovingShift,MODE_CLOSE,PRICE_CLOSE,4);
   maee=iMA("EURGBP",0,MovingPeriod,MovingShift,MODE_CLOSE,PRICE_CLOSE,4);
   mauu=iMA("GBPUSD",0,MovingPeriod,MovingShift,MODE_CLOSE,PRICE_CLOSE,4);   
  
//---- sell conditions
    if ((Close[1]<ma) && (val<val1) && (val2<val21) && (val3<val31) && TimeStamp!=iTime(Symbol(),0,0))
       if(Hour() >= TimeOpen && Hour() <= TimeClose) 	
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICMA,0,Red);
      return;
     }
//---- buy conditions
  if ((Close[1]>ma)  && (val>val1) && (val2>val21) && (val3>val31) && TimeStamp!=iTime(Symbol(),0,0))
     if(Hour() >= TimeOpen && Hour() <= TimeClose) 
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICMA,0,Blue);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
      
        {
       if((Hour() < TimeOpen && Hour() > TimeClose)) 
       OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
       if((Hour() < TimeOpen && Hour() > TimeClose))
        OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }
//+------------------------------------------------------------------+